Installation
============

``xmldiff`` is a standard Python package and can be installed in all the ways Python packages normally can be installed.
The most common way is to use ``pip``::

  pip install xmldiff

You can also download the latest version from `The Cheeseshop a.k.a PyPI <https://pypi.org/project/xmldiff/>`_,
unpack it with you favourite unpacking tool and then run::

  python setup.py install

That's it, ``xmldiff`` should now be available for you to use.

Several Unix distributions also include ``xmldiff`` so you can install it with your distrubutions package manager.
Be aware that currently most distribute an earlier version,
typically 0.6.10, which is very different from 2.x,
which this documentation is written for.
You can check this by running ``xmldiff --version``.
